==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.share.impl/src/com/openexchange/share/impl/cleanup/BackgroundGuestCleaner.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.share.impl.cleanup;

import java.util.concurrent.BlockingQueue;
import java.util.concurrent.atomic.AtomicBoolean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * {@link BackgroundGuestCleaner}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.8.0
 */
public class BackgroundGuestCleaner implements Runnable {

    private static final Logger LOG = LoggerFactory.getLogger(BackgroundGuestCleaner.class);
    private final BlockingQueue<GuestCleanupTask> cleanupTasks;
    private final AtomicBoolean active;

    /**
     * Initializes a new {@link BackgroundGuestCleaner}.
     *
     * @param cleanupTasks The queue yielding cleanup tasks for the worker
     */
    public BackgroundGuestCleaner(BlockingQueue<GuestCleanupTask> cleanupTasks) {
        super();
        this.cleanupTasks = cleanupTasks;
        this.active = new AtomicBoolean(true);
    }

    /**
     * Stops all background processing by signaling termination flag.
     */
    public void stop() {
        active.set(false);
    }

    @Override
    public void run() {
        LOG.info("Background guest cleaner starting.");
        while (active.get()) {
            try {
                GuestCleanupTask task = cleanupTasks.take();
                if (LOG.isDebugEnabled()) {
                    LOG.debug("Starting cleanup task {}.", task);
                    long start = System.currentTimeMillis();
                    task.call();
                    LOG.debug("Guest cleanup task {} finished after {}ms.", task, (System.currentTimeMillis() - start));
                } else {
                    task.call();
                }
            } catch (InterruptedException e) {
                Thread.currentThread().interrupt();
                return;
            } catch (Exception e) {
                LOG.error("Error during guest cleanup", e);
            }
        }
        LOG.info("Background guest cleaner stopped.");
    }

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.share.impl/src/com/openexchange/share/impl/cleanup/BackgroundGuestCleaner.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.share.impl.cleanup;

import static com.openexchange.java.Autoboxing.L;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.atomic.AtomicBoolean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * {@link BackgroundGuestCleaner}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.8.0
 */
public class BackgroundGuestCleaner implements Runnable {

    private static final Logger LOG = LoggerFactory.getLogger(BackgroundGuestCleaner.class);
    private final BlockingQueue<GuestCleanupTask> cleanupTasks;
    private final AtomicBoolean active;

    /**
     * Initializes a new {@link BackgroundGuestCleaner}.
     *
     * @param cleanupTasks The queue yielding cleanup tasks for the worker
     */
    public BackgroundGuestCleaner(BlockingQueue<GuestCleanupTask> cleanupTasks) {
        super();
        this.cleanupTasks = cleanupTasks;
        this.active = new AtomicBoolean(true);
    }

    /**
     * Stops all background processing by signaling termination flag.
     */
    public void stop() {
        active.set(false);
    }

    @Override
    public void run() {
        LOG.info("Background guest cleaner starting.");
        while (active.get()) {
            try {
                GuestCleanupTask task = cleanupTasks.take();
                if (LOG.isDebugEnabled()) {
                    LOG.debug("Starting cleanup task {}.", task);
                    long start = System.currentTimeMillis();
                    task.call();
                    LOG.debug("Guest cleanup task {} finished after {}ms.", task, L((System.currentTimeMillis() - start)));
                } else {
                    task.call();
                }
            } catch (InterruptedException e) {
                Thread.currentThread().interrupt();
                return;
            } catch (Exception e) {
                LOG.error("Error during guest cleanup", e);
            }
        }
        LOG.info("Background guest cleaner stopped.");
    }

}
